黑天鹅 (豆瓣)
Description: 黑天鹅电影简介和剧情介绍,黑天鹅影评、图片、预告片、影讯、论坛、在线购票
Keywords: 黑天鹅,Black Swan,黑天鹅影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.195豆瓣电影Top250

# 黑天鹅 Black Swan (2010)

导演: 达伦·阿伦诺夫斯基
编剧: 安德雷斯·海因斯 / 马克·海曼 / 约翰·J·麦克劳克林
主演: 娜塔莉·波特曼 / 米拉·库尼斯 / 文森特·卡索 / 芭芭拉·赫希 / 薇诺娜·瑞德 / 本杰明·米派德 / 克塞尼亚·索罗 / 克里斯汀娜·安娜波 / 詹妮特·蒙哥马利 / 塞巴斯蒂安·斯坦 / 托比·海明威 / 塞尔吉奥·托拉多 / 马克·马戈利斯 / 蒂娜·斯隆 / 亚伯拉罕·阿罗诺夫斯基 / 夏洛特·阿罗诺夫斯基 / 玛西娅·让·库尔茨 / 肖恩·奥哈根 / 克里斯托弗·加廷 / 黛博拉·奥夫纳 / 斯坦利·B·赫尔曼 / 库尔特·弗勒曼 / 帕特里克·赫辛格 / 莎拉·海伊
类型: 剧情 / 惊悚
制片国家/地区: 美国
语言: 英语 / 法语 / 意大利语
上映日期: 2010-09-01(威尼斯电影节) / 2010-12-17(美国)
片长: 108分钟 / 103分钟(威尼斯电影节)
又名: 夺命黑天鹅 / 霸王别鹅(豆友译名)
IMDb: tt0947798
豆瓣评分
引用
8.6
753964人评价
5星
42.3%
4星
45.2%
3星
11.5%
2星
0.8%
1星
0.2%
好于 98% 惊悚片
好于 96% 剧情片
想看 看过
评价:
推荐

## 黑天鹅的剧情简介 · · · · · ·

纽约剧团要重排《天鹅湖》，因前领舞Beth（薇诺娜•赖德 Winona Ryder 饰）离去，总监Thomas（文森特•卡索尔 Vincent Cassel. 饰）决定海选新领舞，且要求领舞要分饰黑天鹅与白天鹅。Nina（娜塔莉•波特曼Natalie Portman 饰）自幼练习芭蕾舞，在母亲的细心关照下，技艺出众。这次，她希望可以脱颖而出。然而，在竞争中，她发现心机颇重的Lily（米拉•库妮丝 Mila Kunis 饰）是自己的强劲对手。在选拔中，她的白天鹅表演的无可挑剔，但是黑天鹅不及Lily。她感到身心俱疲，回家还发现了背部的红斑与脚伤。她一个人找到总监，希望争取一下。总监趁机亲吻她，却被她强硬拒绝。结果，总监居然选了她。队友怀疑她靠色相上位。在酒会上，Beth甚至当众发泄。这种压力外加伤病，一直影响着她的发挥。总监启发她要释放激情，表现出黑天... (展开全部) 纽约剧团要重排《天鹅湖》，因前领舞Beth（薇诺娜•赖德 Winona Ryder 饰）离去，总监Thomas（文森特•卡索尔 Vincent Cassel. 饰）决定海选新领舞，且要求领舞要分饰黑天鹅与白天鹅。Nina（娜塔莉•波特曼Natalie Portman 饰）自幼练习芭蕾舞，在母亲的细心关照下，技艺出众。这次，她希望可以脱颖而出。然而，在竞争中，她发现心机颇重的Lily（米拉•库妮丝 Mila Kunis 饰）是自己的强劲对手。在选拔中，她的白天鹅表演的无可挑剔，但是黑天鹅不及Lily。她感到身心俱疲，回家还发现了背部的红斑与脚伤。她一个人找到总监，希望争取一下。总监趁机亲吻她，却被她强硬拒绝。结果，总监居然选了她。队友怀疑她靠色相上位。在酒会上，Beth甚至当众发泄。这种压力外加伤病，一直影响着她的发挥。总监启发她要释放激情，表现出黑天鹅的诱惑。在强大的心理暗示中，她似乎也滑向了黑天鹅的角色…… ©豆瓣

## 黑天鹅的演职员 · · · · · · ( 全部 37 )

- 达伦·阿伦诺夫斯基 导演
- 娜塔莉·波特曼 饰 妮娜·赛耶斯 Nina Sayers / The Swan Queen
- 米拉·库尼斯 饰 莉莉 Lily / The Black Swan
- 文森特·卡索 饰 托马斯·勒罗伊 Thomas Leroy / The Gentleman
- 芭芭拉·赫希 饰 艾丽卡·赛耶斯 Erica Sayers / The Queen
- 薇诺娜·瑞德 饰 贝丝·麦金太尔 Beth Macintyre / The Dying Swan

## 黑天鹅的视频和图片 · · · · · · ( 预告片1 | 添加视频评论 | 图片961 · 添加 )

## 黑天鹅的获奖情况 · · · · · · ( 全部 )

- 第83届奥斯卡金像奖
- 最佳影片(提名)
- 迈克·麦达沃伊 / 斯科特·富兰克林 / 布赖恩·奥利弗

- 第67届威尼斯电影节
- 金狮奖(提名)
- 达伦·阿伦诺夫斯基

- 第68届金球奖
- 电影类 最佳剧情片(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  恐怖游轮

  闪灵

  禁闭岛

  沉默的羔羊

  致命ID

  孤儿怨

  第六感

  记忆碎片

  惊魂记

  穆赫兰道

我要写短评

## 黑天鹅的短评 · · · · · · ( 全部 170313 条 )

热门 / 最新 / 好友

### 8636 有用 Lou Lou 看过 2010-12-12 15:50:14

那一颗星星是被吓掉的

### 1726 有用 黄妖柒 看过 2010-12-20 12:05:47

有点无聊 教育我们不要逼自己太紧

### 1324 有用 sasasasa 看过 2010-12-21 20:53:36

演的太像戏，拍的很刻意，惊你妹悚啊

### 5118 有用 XU 看过 2010-12-20 17:34:07

舞台上那段黑天鹅太惊艳了！！！！！！Natalie这牛逼演技！！！！！！

### 522 有用 jojo 看过 2010-12-21 03:12:46

就是个外国版“不疯靡不成活”的故事，加那么一点《钢琴教师》的桥段，怎么说呢，虽然natalie很用力在演，不过总觉得缺了点什么。剧本如人，可能是神经太紧绷了，反就不容易好。

> 更多短评 170313条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 黑天鹅的影评 · · · · · · ( 全部 2548 条 )

热门 / 最新 / 好友
张天翼 2010-12-28 12:39:43

## 白羽黑翼，疯魔了小青衣

这篇影评可能有剧透

一、意象： 1、颜色和衣饰 颜色的喻意最常用也最明显。 白色、粉色：白天鹅、妮娜。黑色：黑天鹅、母亲、莉莉、贝丝。灰色：唯一的男主角——舞团艺术总监托马斯。 白色：妮娜的枕头是黑白花纹的，在多个梦醒的俯看镜头中，她的头颅都正好搁在黑色藤蔓花纹盘绕纠缠的中心；她的... (展开)
17127 469 939回应 收起
路易斯的心 2011-04-21 11:18:20

## 一个没有性魅力的人，做什么事都不会成功（文末新增，6年后的时空对话）

这篇影评可能有剧透

“你喜欢做爱吗？ “啊？” “就是性。你喜欢吗？” “……” “我们必须敞开聊。” “……” “给你留个小作业。回家，触摸自己。” “……” “慢慢地。” “……” （互相沉默数秒） “明天还要工作。门卫会为你叫出租车。” 宣布公演主角的庆功晚宴后，艺术总监Thomas将女... (展开)
9545 499 708回应 收起
索尔失地蚊 2010-12-10 16:32:01

## Dance (together) with your heart

这篇影评可能有剧透

在大规模上映之后，又去影院看了一遍。了解剧情的情况下，这次更是能够专注到一些上回看不到或者注意不到的细节，也能对电影整体有些思考。其中几点感觉比较强烈就加在开头。并且补充两个关于电影中配角的理论 整体上最强烈的感觉还是Natalie Portman的精湛表演。记得在Lost剧... (展开)
2664 141 279回应 收起
TORO VAN DARKO 2010-12-22 04:37:55

## 波兰斯基附体

这篇影评可能有剧透

达伦曾直言不讳说《黑天鹅》的创作灵感深受《怪房客》《冷血惊魂》所影响，结果看片后发现果不其然，达伦就像波兰斯基附体，用充满了心理暗示和线索的镜头讲诉了这个关于人格分裂的心理惊悚故事。 波兰斯基电影中的主角多为身不由己，被环境控制被旁人影响，正... (展开)
697 78 92回应 收起
小小农 2010-12-23 14:49:09

## 《黑天鹅》她是自恋又自我厌恶的

我对某些状况的归类有着与生俱来的热情与敏感。“好人难做”一句话可以有多种理解的立场，但没听谁说过“坏人难做”的，但我觉得它们是相斥共存的关系，不过是个找谁代言的问题，就像天使与恶魔，它们在各自的领域都做到了最专业，只是不要试图混合它们。其实，人类不知不觉遗... (展开)
854 82 121回应 收起
hasukihaga 2010-12-17 20:36:23

## 匿藏心底的恶之花

这篇影评可能有剧透

(原文在hasukihaga.blog.163.com ，此帖省略了一些时事的联想片段） 你毒牙般的辞藻令人望而生畏 　　我却在它们背后看到一个受苦的灵魂 　　 　　如在炼狱中煎熬 　　到处是烧红的铁与滚烫的岩浆 　　你在肉体的狂欢中寻找天堂的美 　　虔诚的心躲在角落里悲泣 ... (展开)
492 89 83回应 收起
老吴 2011-01-08 16:42:47

## “乖”的本质是压抑——《黑天鹅》观后感

这篇影评可能有剧透

从来没看过真的芭蕾，也不理解芭蕾有什么好看的。《黑天鹅》让我对于芭蕾艺术有种豁然开朗的认识。但导演选择《天鹅湖》作为线索显然意图非常明确，它借用了黑白两只天鹅的形象，来推动对于人性中两种本质的探究。 故事是这样的：剧团要重排《天鹅湖》，因前领舞Beth离去，... (展开)
580 20 39回应 收起
逍遥兽 2011-01-05 09:48:00

## 殉欲者•殉舞者

入评理由：一个人与自己的角力，可以这么狂乱而优美。 片 名：《黑天鹅》 导 演：达伦•阿罗诺夫斯基 主 演：娜塔丽•波曼、米拉•库妮丝、薇诺娜•瑞德、文森特•卡索、芭芭拉•赫希 上映时间：2010年12月 读 家：石头花园的歌女 料不到年末竟有这样... (展开)
249 7 28回应 收起
文艺复兴人 2010-12-14 07:26:01

## 新瓶装旧酒

一部电影想要行至中段的时候让观众们疑神疑鬼摸不到头脑是很简单的事情，结尾能否圆场才是判断高下的关键。幸运的是，《黑天鹅》至少还能自圆其说，遗憾的是，它自圆其说的方式是如此的偷懒而且毫无原创性。当然，结尾还是可以给我们带来差强人意的满足感，但是这更多的来源于... (展开)
203 81 77回应 收起
_D 2010-12-24 23:21:13

## 精神病人Nina之病情分析

弗洛伊德的理论果然十分好用，我看到一半时就给Nina做了一些诊断，主要从精神分析法入手，Nina的病因无非两点：性压抑以及早期经验也就是童年境遇的影响，她母亲想必是一时不慎有了孩子，于是结束了舞台生涯，转而将自己的愿望投射到女儿身上，她不仅希望女儿实现她的舞台理想... (展开)
250 28 46回应 收起

> 更多影评 2548篇

添加新讨论

## 讨论区 · · · · · ·

娜塔莉最后死了没有？这里有正确的解答。 | 来自红尘 | 6 回应 | 2022-11-21 02:02:12
为什么这部电影评分这么高？ | 来自把咬分开念呀 | 19 回应 | 2022-11-21 02:01:27
突然想到了吴谢宇案… | 来自乌鹊南飞 | 6 回应 | 2022-11-17 07:28:35
我觉得女主跳天鹅皇后在她单独去找总监之前就已经... | 来自Whateverwillbe |  | 2022-11-13 22:58:47
nina带回家的人到底是lily还是另外男的？如果是男... | 来自一颗胖桔梗 | 6 回应 | 2022-11-13 22:17:16

> 去这部影片的讨论区（全部204条）

## 关于《黑天鹅》的问题 · · · · · · ( 全部37个 )

- 妮娜获得角色回家和母亲庆祝时的蛋糕那幕？ 8人回答
- Nina和Lily确实上床了吗？还是幻想出来的？ 13人回答

> 全部37个问题

## 在哪儿看这部电影 · · · · · ·

- 爱奇艺视频 VIP免费观看
- 腾讯视频 VIP免费观看
- 西瓜视频 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 《身不在场》：木卫二在纸媒时代的电影推荐 (木卫二)
- 2011第十四届上海国际电影节影片介绍大全 (妖灵妖)
- 有生之年非看不可的1001部电影 (Viking)
- 带你进入不正常的世界 (DK小眼镜儿)

## 谁在看这部电影 · · · · · ·

- Scanker
  1分钟前 看过
- 豆友yjPW0uFtHg
  1分钟前 看过
- 杨坚强
  9分钟前 看过

1174818人看过 / 265145人想看

订阅黑天鹅的评论:
feed: rss 2.0